@@ -1006,7 +1006,7 @@ static void Redisplay(Widget w, XEvent *event, Region region)
    TOPLOC = newtop;
    SHOWNLENGTH = newbot-newtop+1;
 
-   (*swclass->threeD_class.shadowdraw) (w, event, region, FALSE);
+   (*swclass->threeD_class.shadowdraw) (w, event, region, sbw->threeD.relief, FALSE);
 
    ENDMESSAGE(Redisplay)
 }
@@ -1385,7 +1385,13 @@ static void NotifyThumb(Widget w, XEvent *event, String *params _GL_UNUSED, Card
     Set the scroll bar to the given location.
 ###############################################################################*/
 
-void XawScrollbarSetThumb (Widget w, double top, double shown)
+void XawScrollbarSetThumb (Widget w,
+#if NeedWidePrototypes
+                                     double top, double shown
+#else
+                                     float top, float shown
+#endif
+                          )
 {
    SCROLLBARWIDGET w;
 
