@@ -34,8 +34,6 @@
 #define	_GV_ERROR_H_
 
 #include <errno.h>
-/* BSD 4.3 errno.h does not declare errno */
-extern int errno;
 
 extern char* open_fail_error (int, char *, char *, int);
 
