@@ -71,8 +71,7 @@
 /*############################################################*/
 
 char *
-file_getDirOfPath(path)
-   char *path;
+file_getDirOfPath(char *path)
 {
    char *dir=NULL;
    char *pos;
@@ -98,8 +97,7 @@ file_getDirOfPath(path)
 /*############################################################*/
 
 char *
-file_locateFilename(path)
-   char *path;
+file_locateFilename(char *path)
 {
    char *tmp=NULL;
    BEGINMESSAGE(file_locateFileName)
@@ -171,9 +169,9 @@ file_getTmpFilename(const char *baseDirectory, const char *baseFilename, int *fi
          l = snprintf(tempFilename, sizeof(tempFilename),
 			 "%.*s/gv_%s_%s.XXXXXX",
 			 len, baseDirectory, tmpName, tmpExt);
-	 if (l < 0 || l >= sizeof(tempFilename) )
+	 if (l < 0 || l >= (int)sizeof(tempFilename) )
 		 break;
-         file_translateTildeInPath(tempFilename);
+         file_translateTildeInPath(tempFilename, sizeof(tempFilename));
 	 oldumask = umask(0077);
 	 fd = mkstemp(tempFilename);
 	 umask(oldumask);
@@ -204,23 +202,20 @@ file_getTmpFilename(const char *baseDirectory, const char *baseFilename, int *fi
 /* Replaces tilde in string by user's home directory. */
 /*############################################################*/
 
-void
-file_translateTildeInPath(path)
-   char *path;
+void file_translateTildeInPath(char *path, size_t s)
 {
-   char *pos;
 
    BEGINMESSAGE(file_translateTildeInPath)
-   if ((pos=strchr(path,'~'))) {
-      char *home;
-      char tmp[GV_MAX_FILENAME_LENGTH];
-      home=getenv("HOME");
-      if (strlen(home)+strlen(path)-1 < GV_MAX_FILENAME_LENGTH-1) {
-         *pos='\0'; pos++;
-         strcpy(tmp,path);
-         strcat(tmp,home);
-         strcat(tmp,pos);
-         strcpy(path,tmp);
+   if (path[0] == '~' && (path[1] == '/' || path[1] == '\0')) {
+      char *home = getenv("HOME");
+
+      if (home != NULL) {
+         size_t pl = strlen(path);
+         size_t hl = strlen(home);
+         if (pl + hl - 1 < s - 1) {
+             memmove(path + hl, path + 1, pl - 1 + 1);
+             memcpy(path, home, hl);
+         }
       }
    }
    ENDMESSAGE(file_translateTildeInPath)
@@ -230,8 +225,7 @@ file_translateTildeInPath(path)
 /* file_fileIsDir */
 /*############################################################*/
 
-int file_fileIsDir(fn)
-  char *fn;
+int file_fileIsDir(char *fn)
 {
   struct stat s;
   int r=0;
@@ -253,8 +247,7 @@ int file_fileIsDir(fn)
 /*############################################################*/
 
 int
-file_fileIsNotUseful(fn)
-  char *fn;
+file_fileIsNotUseful(char *fn)
 {
   struct stat s;
   int r=0;
@@ -282,10 +275,9 @@ file_fileIsNotUseful(fn)
 /* If the file ends in .pdf, change this to .ps.*/
 /* Return pointer to temp copy if changed, else to input string. */
 /*############################################################*/
- 
+
 char *
-file_pdfname2psname (name)
-  char *name;
+file_pdfname2psname(char *name)
 {
   char *e;
 
@@ -312,10 +304,9 @@ file_pdfname2psname (name)
 /*############################################################*/
 /* file_getUsefulName */
 /*############################################################*/
- 
+
 char *
-file_getUsefulName(name)
-  char *name;
+file_getUsefulName(char *name)
 {
   char *e,*c;
   String mext,ext;
