@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -33,41 +33,10 @@
 #ifndef	_GV_INFO_H_
 #define	_GV_INFO_H_
 
-extern void	makeInfoPopup (
-#if NeedFunctionPrototypes
-#endif
-);
-
-extern void	cb_popupInfoPopup (
-#if NeedFunctionPrototypes
-   Widget,
-   XtPointer,
-   XtPointer
-#endif
-);
-
-extern void	cb_popdownInfoPopup (
-#if NeedFunctionPrototypes
-   Widget,
-   XtPointer,
-   XtPointer
-#endif
-);
-
-extern void	cb_appendInfoPopup (
-#if NeedFunctionPrototypes
-   Widget,
-   XtPointer,
-   XtPointer
-#endif
-);
-
-extern void	cb_resetInfoPopup (
-#if NeedFunctionPrototypes
-   Widget,
-   XtPointer,
-   XtPointer
-#endif
-);
+extern void makeInfoPopup (void);
+extern void cb_popupInfoPopup (Widget, XtPointer, XtPointer);
+extern void cb_popdownInfoPopup (Widget, XtPointer, XtPointer);
+extern void cb_appendInfoPopup (Widget, XtPointer, XtPointer);
+extern void cb_resetInfoPopup (Widget, XtPointer, XtPointer);
 
 #endif	/* _GV_INFO_H_ */
