@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -41,15 +41,9 @@
   options
 ##############################################*/
 
-typedef void (*OptionPopupCreateProc)(
-#if NeedFunctionPrototypes
-#endif
-);
+typedef void (*OptionPopupCreateProc)(void);
 
-typedef void (*OptionPopupUpdateProc)(
-#if NeedFunctionPrototypes
-#endif
-);
+typedef void (*OptionPopupUpdateProc)(void);
 
 typedef struct OptionPopupStruct_ {
   Widget popup;
@@ -109,12 +103,7 @@ typedef struct ScaleStruct_ {
   process
 ##############################################*/
 
-typedef void (*ProcessNotifyProc)(
-#if NeedFunctionPrototypes
-   XtPointer  /* data */,
-   int        /* type */
-#endif
-);
+typedef void (*ProcessNotifyProc)(XtPointer /* data */, int /* type */);
 
 #define PROCESS_NONE	0
 #define PROCESS_NOTIFY	1
